![Boa Logo](https://raw.githubusercontent.com/kentaasvang/boa/master/img/boa.png)

![issues](https://img.shields.io/github/issues/kentaasvang/boa) ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pboa) ![PyPI](https://img.shields.io/pypi/v/pboa)

# Boa - a python project manager
boa is a simple CLI for python that makes it easy to set up new python-projects. It aims to make a clean project-layout with sensible defaults, without assuming any dependecies what-so-ever. 

The CLI's API isn't decided yet. It will either stay as-is, or move towards the same API as the dotnet-CLI.

The project-layout is inspired by [this document](https://docs.python-guide.org/writing/structure/)


### Installing
Install `boa` with **pip**
```terminal
>>> pip install pboa
```


### Usage
To create a new project run the command:
```terminal
$ boa new <project-name>
```
This will create your project at your current working directory


### Contributing
All contributions are very welcome, we are all here to learn. You can: try to install and run the project, write issues or report bugs, problems or just general criticism. Any feedback is also welcome! As well as requests or suggestions for improvements. You can also tackle some of the issues that are already registered and submit pull requests. All contributions no matter how small will be credited


